@@ -1,10 +1,10 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2008-2015 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -13,10 +13,9 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
 #ifndef __ROTARY_H
@@ -28,7 +27,7 @@
 #include <clxclient.h>
 
 
-class RotaryImg
+class RotaryGeom
 {
 public:
 
@@ -52,9 +51,10 @@ public:
 
     RotaryCtl (X_window    *parent,
                X_callback  *cbobj,
-               RotaryImg   *image,
-	       int xp, int yp,
-               int cbind = 0);
+	       int          cbind,
+               RotaryGeom  *rgeom,
+	       int          xp,
+               int          yp);
 
     virtual ~RotaryCtl (void);
 
@@ -78,7 +78,7 @@ protected:
 
     X_callback  *_cbobj;
     int          _cbind;
-    RotaryImg   *_image;
+    RotaryGeom  *_rgeom;
     int          _state;
     int          _count;
     int          _range;
