@@ -33,6 +33,7 @@ XImage  *notesect_img;
 XImage  *ctrlsect_img;
 XImage  *redzita_img;
 XImage  *b_note_img;
+XImage  *b_llat_img;
 XImage  *b_midi_img;
 
 RotaryGeom  r_tune_geom;
@@ -76,6 +77,7 @@ void styles_init (X_display *disp, X_resman *xrm)
     notesect_img = loadpng ("notesect", disp, XftColors [C_MAIN_BG]);
     ctrlsect_img = loadpng ("ctrlsect", disp, XftColors [C_MAIN_BG]);
     redzita_img  = loadpng ("redzita",  disp, XftColors [C_MAIN_BG]); 
+    b_llat_img   = loadpng ("llat", disp, XftColors [C_MAIN_BG]);
     b_midi_img   = loadpng ("midi", disp, XftColors [C_MAIN_BG]);
     b_note_img   = loadpng ("note", disp, XftColors [C_MAIN_BG]);
     Tmeter::_scale = loadpng ("hscale",  disp, XftColors [C_MAIN_BG]);
